"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RelatedPackagesValidator = void 0;
/**
 * Validates package groups that should match for best compatibility
 */
var RelatedPackagesValidator = /** @class */ (function () {
    function RelatedPackagesValidator() {
        /** List of related dependencies that should share the same version number */
        this.depsGroups = [
            ["babel-plugin-react-native-web", "react-native-web"],
            ["babel-jest", "jest"],
            ["@typescript-eslint/eslint-plugin", "@typescript-eslint/parser"]
        ];
        this.depsGroupsMap = {};
        this.depFileGroupMap = {};
        console.log("Validating Related packages");
        this.depsGroupsMap = this.depsGroups.reduce(function (map, arr, index) {
            arr.forEach(function (element) {
                map[element] = index.toString(); // eslint-disable-line no-param-reassign
            });
            return map;
        }, {});
    }
    RelatedPackagesValidator.prototype.addDependency = function (dependency, version, filename) {
        var groupKey = this.depsGroupsMap[dependency];
        if (dependency in this.depsGroupsMap) {
            if (!(groupKey in this.depFileGroupMap)) {
                this.depFileGroupMap[groupKey] = {};
            }
            if (!(version in this.depFileGroupMap[groupKey])) {
                this.depFileGroupMap[groupKey][version] = {};
            }
            if (!(dependency in this.depFileGroupMap[groupKey][version])) {
                this.depFileGroupMap[groupKey][version][dependency] = [];
            }
            this.depFileGroupMap[groupKey][version][dependency].push(filename);
        }
    };
    RelatedPackagesValidator.prototype.validate = function () {
        var _this = this;
        var isValid = true;
        Object.keys(this.depFileGroupMap).forEach(function (group) {
            if (Object.keys(_this.depFileGroupMap[group]).length > 1) {
                if (isValid) {
                    console.log("The following dependencies versions should match, please check them");
                    isValid = false;
                }
                console.log(_this.depsGroups[+group], _this.depFileGroupMap[group]);
            }
        });
        return isValid;
    };
    return RelatedPackagesValidator;
}());
exports.RelatedPackagesValidator = RelatedPackagesValidator;
